*Do-file to Estimate Substitution Elasticities

*The elasticity estimation code in this do-file accompanies USITC report, "Cucumbers: Effect of Imports on U.S. Seasonal Markets, with a Focus on the U.S. Southeast", Inv. 332-583. The report includes a quantitative analysis of the economic impact of fresh cucumber imports on U.S. domestic prices, production, revenue, operating income, and employment. This file estimates the substitution elasticity parameter that describes how consumers shift product sourcing after a relative price change. 

*The stata code requires a panel of U.S. imports data for cucumbers (HTS code 0707.00), by trade partner, import district, month and year. More details on the data used in the estimation procedure can be found in Appendix E. 

* Country: trade partner
* District: location of entry into U.S. 
* Datatype: customs value or landed-duty paid value

clear
cd "<working file path>"

import excel using "Estimationdata.xlsx", firstrow /*Imports data can be downloaded here: https://dataweb.usitc.gov/ */

******Organize data******
keep if substr(HTSNumber,1,7)=="0707.00"
drop HTSNumber
replace DataType="cv" if DataType=="Customs Value"
replace DataType="ldpv" if DataType=="Landed Duty-Paid Value"
rename JAN month1
rename FEB month2
rename MAR month3
rename APR month4
rename MAY month5
rename JUN month6
rename JUL month7
rename AUG month8
rename SEP month9
rename OCT month10
rename NOV month11
rename DEC month12

collapse (sum) month1 month2 month3 month4 month5 month6 month7 month8 month9 month10 month11 month12, by(Country District Year DataType) /*collapses data to HTS6 level if it was downloaded at HTS8 level*/

reshape long month, i(Country District Year DataType) j(Mon, string)
rename month Value
sort DataType Year Mon
reshape wide Value, i(Country District Year Mon) j(DataType, string)
sort Year Mon
rename Valuecv cv
rename Valueldpv ldpv

gen season = 0 /*organizes data by season designations used in report*/
replace season = 1 if Mon=="6"
replace season = 1 if Mon=="7"
replace season = 1 if Mon=="8"
replace season = 1 if Mon=="9"
replace season = 1 if Mon=="10" 

collapse (sum) cv ldpv, by(Country District Year season) /*collapses by season*/

save Estimationdata, replace /*creates a copy of dataset used in regression*/

******Generate variables used in the regression******
gen ln_ldpv=ln(ldpv) /*log of trade flows*/
gen ln_ldprat=ln(ldpv/cv) /*trade cost measure*/
sort Country District
destring Year, replace

gen period = Year*100+season
encode District, gen(ndi)
encode Country, gen(nco)
gen fe_ct = period*100+nco /*country time fixed effects*/
gen fe_dt = period*100+ndi /*district time fixed effects*/
format %20.0f fe_dt
format %20.0f fe_ct

******Run regression and generate estimate******
quietly xi: reg ln_ldpv ln_ldprat i.fe_ct i.fe_dt, vce(robust)
lincom 1-_b[ln_ldprat]